import {Button, Text, Textarea, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import Taro from "@tarojs/taro";
import './topic.scss'

interface Props {
  data: ShareSubject
  onAnswer: (isAnswer: boolean) => void
  onUpAndDown?: (index: number) => void
  index: number
  validate: boolean
  frequency?: number
}

const ShortAnswer: FC<Props> = ({data, onAnswer, onUpAndDown, index, validate, frequency}) => {
  const [value, setValue] = useState<string>('')

  function onBlur() {
    if (value.length < 3) {
      Taro.showToast({title: '最少3个字', icon: 'error'})
    }
  }

  useEffect(() => {
    if (validate) {
      if (value.length < 3) {
        onAnswer(false)
      } else {
        onAnswer(true)
      }
    }
  }, [validate])

  return (
    <View className='topic'>
      <View className='mb-3'>
        <Text style={{
          display: 'inline-block',
          verticalAlign: 'middle',
          fontSize: '20rpx',
          height: '34rpx',
          background: '#45D4A8',
          borderRadius: '8rpx',
          color: '#fff',
          padding: '0 2px',
          marginRight: '8px'
        }}>简答题</Text>
        <Text>{data.question}</Text>
      </View>
      <Textarea
        placeholder='请输入答案'
        adjustPosition
        className='Textarea'
        onBlur={onBlur}
        onInput={(e) => setValue((e.target as HTMLTextAreaElement).value)}/>
      <View>最少3个字</View>

      {onUpAndDown && <View className='upAndDown'>
        {index > 0 && <Button className='button' onClick={() => onUpAndDown?.(index - 1)}>上一题</Button>}
        <Button className='button' onClick={() => onUpAndDown?.(index + 1)}>下一题</Button>
      </View>}



      {frequency == 0 && <View className='mt-3'>
        <View className='font-weight my-3'>题目解析</View>
        <View>{data.analysis}</View>
      </View>}

    </View>
  )
}

export default ShortAnswer
