import {FC, useState} from "react";
import Tabs, {OnChangOpt} from "@/components/tabs/tabs";
import {Button, View} from "@tarojs/components";
import {CourseDepData} from "@/api";
import Collapse from "@/components/collapse/collapse";
import Hours from "@/pages/business/videoInfo/components/hours";
import Taro from "@tarojs/taro";

interface Props {
  data: CourseDepData | null
  setHors: (is_complete: boolean, id: number) => void
  id: number
}

const tabList = [
  {title: '介绍', value: 0},
  {title: '目录', value: 1},
  // {title: '评价', value: 2},
]


const Catalogue: FC<Props> = ({data, setHors, id}) => {
  const [current, setCurrent] = useState(1)

  function jumCurHistory() {
    Taro.preload({course_id: id, name: data?.course.title})
    Taro.navigateTo({url: `/pages/business/curHistory/curHistory`})
  }

  function tabChange({tab}: OnChangOpt) {
    setCurrent(tab?.value as number)
  }

  function getHors(chapter_id?: number): Hour[] | null {
    for (const d of Object.values(data?.hours || {})) {
      if (d[0].chapter_id === chapter_id) {
        return d
      }
    }
    return null
  }

  function chapters_complete(chapter: Chapters): boolean {
    const hors = getHors(chapter.id)
    if (hors) {
      for (const hor of hors) {
        const courseHourRecordsFinish = data?.learn_hour_records?.find(d => d.id === hor.id)?.courseHourRecordsFinish
        if (courseHourRecordsFinish === 0 || !courseHourRecordsFinish) {
          return false
        }
      }
      return true
    }
    return false
  }

  function upChaptersOver(is_complete: boolean, id: number, index: number) {
    if (!index) {
      setHors(is_complete, id)
    } else {
      const ok = chapters_complete((Object.values(data?.chapters || {})?.[index - 1]))
      if (!ok) {
        Taro.showModal({title: '上一章节未完成'})
        return
      }
      setHors(is_complete, id)
    }
  }

  return (
    <>
      <View className='catalogue'>
        <Tabs tabList={tabList} onChange={tabChange} current={current}/>
        <View className='py-2 hours'>
          {current === 0 && <View className='short_desc'>{data?.course.short_desc || '无'}</View>}
          {current === 1 && <View>
            <View className='font-weight mb-2'>课程目录</View>
            {data?.chapters.length ? Object.values(data?.chapters || {}).map((d, index) => <View>
                <Collapse title={`${index + 1}.${d.name}`}>
                  <Hours
                    click={(is_complete, id) => upChaptersOver(is_complete, id, index)}
                    learn_hour_records={data.learn_hour_records}
                    data={getHors(d.id)}
                  />
                </Collapse>
              </View>)
              : <Hours data={data?.hours?.[0]} click={setHors} learn_hour_records={data?.learn_hour_records}/>}
          </View>}
          {current === 2 && <View className='text-center'>评论暂未开放</View>}
        </View>
      </View>

      <View className='Videobutton'>
        <Button className='button' onClick={jumCurHistory}>查看学习记录</Button>
      </View>
    </>
  )
}

export default Catalogue
